package com.qmth.themis.business.service.impl;

import java.util.Date;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.themis.business.bean.exam.FaceVerifyBean;
import com.qmth.themis.business.cache.RedisKeyHelper;
import com.qmth.themis.business.cache.bean.FaceVerifyCacheBean;
import com.qmth.themis.business.dao.TOeFaceVerifyHistoryMapper;
import com.qmth.themis.business.entity.TOeFaceVerifyHistory;
import com.qmth.themis.business.enums.ExamTypeEnum;
import com.qmth.themis.business.enums.FaceVerifyExceptionEnum;
import com.qmth.themis.business.service.TOeFaceVerifyHistoryService;
import com.qmth.themis.business.util.RedisUtil;
import com.qmth.themis.common.contanst.Constants;

/**
 * @Description: 人脸验证记录 服务实现类
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2020/6/25
 */
@Service
public class TOeFaceVerifyHistoryServiceImpl extends ServiceImpl<TOeFaceVerifyHistoryMapper, TOeFaceVerifyHistory> implements TOeFaceVerifyHistoryService {

	
	@Resource
	RedisUtil redisUtil;
	
	@Override
	public FaceVerifyBean verify(Long recordId, String type, String photoUrl, Integer faceCount, Double similarity,
			Double realness, Long time, String exception) {
		FaceVerifyCacheBean cache=new FaceVerifyCacheBean();
		cache.setId(Constants.idGen.next());
		cache.setExamRecordId(recordId);
		cache.setFaceCount(faceCount);
		cache.setException(FaceVerifyExceptionEnum.valueOf(exception));
		cache.setPhotoUrl(photoUrl);
		cache.setRealness(realness);
		cache.setSimilarity(similarity);
		cache.setType(ExamTypeEnum.valueOf(type));
		cache.setTime(time);
		redisUtil.set(RedisKeyHelper.faceVerifyCacheKey(cache.getId()), cache);
		FaceVerifyBean ret=new FaceVerifyBean();
		ret.setId(cache.getId());
		ret.setUpdateTime(new Date().getTime());
		return ret;
	}

	@Transactional
	@Override
	public void save(Long id, Long recordId, String type, String photoUrl, Integer faceCount, Double similarity,
			Double realness, Long time, String exception) {
		TOeFaceVerifyHistory entity=new TOeFaceVerifyHistory();
		entity.setId(id);
		entity.setExamRecordId(recordId);
		entity.setFaceCount(faceCount);
		entity.setException(FaceVerifyExceptionEnum.valueOf(exception));
		entity.setPhotoUrl(photoUrl);
		entity.setRealness(realness);
		entity.setSimilarity(similarity);
		entity.setType(ExamTypeEnum.valueOf(type));
		entity.setTime(time);
		saveOrUpdate(entity);
	}

}
